alias_set

Function alias_set 

pub fn alias_set(
    name: &str,
    card_id: &str,
    pkg: Option<&str>,
    note: Option<&str>,
) -> Result<Alias, String>
Bind (or rebind) an alias to a Card.

Validates that card_id exists. If an alias with the same name already exists it is overwritten — the alias table is intentionally mutable even though the Cards themselves are not.