pub fn register_env(
lua: &Lua,
alc_table: &Table,
env_map: Arc<HashMap<String, String>>,
) -> Result<()>Expand description
Register alc.env on the given alc table and store the snapshot as
side-band app-data on lua so fork children can inherit it via
lua.app_data_ref::<Arc<HashMap<String,String>>>().
This function is intentionally pub (not pub(super)) because it is
re-exported from bridge::mod.rs and called from executor.rs and
fork.rs outside this module.