pub struct SessionRegistry { /* private fields */ }Expand description
Manages active sessions. Replaces the raw SessionMap.
Implementations
Sourceimpl SessionRegistry
impl SessionRegistry
pub fn new() -> Self
Sourcepub async fn start_execution(
&self,
session: Session,
) -> Result<(String, FeedResult), SessionError>
pub async fn start_execution( &self, session: Session, ) -> Result<(String, FeedResult), SessionError>
Start execution and wait for first event (pause or completion).
Sourcepub async fn feed_response(
&self,
session_id: &str,
query_id: &QueryId,
response: String,
) -> Result<FeedResult, SessionError>
pub async fn feed_response( &self, session_id: &str, query_id: &QueryId, response: String, ) -> Result<FeedResult, SessionError>
Feed one response to a paused session by query_id.
If this completes all pending queries, the session resumes and returns the next event (Paused or Finished). If queries remain, returns Accepted { remaining }.